@@ -36,18 +36,18 @@ if (empty($lang) || !is_array($lang))
 // in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine
 
 $lang = array_merge($lang, array(
-	'ACP_IMAGESETS_EXPLAIN'	=> 'Les ensembles d’images comprennent toutes les images de boutons, de forums, de dossiers, etc. Ils comprennent également d’autres images qui ne sont pas spécifiques au style utilisé sur le forum. Vous pouvez éditer, exporter ou supprimer ici les ensembles d’images et en importer ou en activer de nouveaux.',
-	'ACP_STYLES_EXPLAIN'	=> 'Vous pouvez gérer ici les styles disponibles sur votre forum. Un style comprend un ensemble de templates, de thèmes et d’images. Vous pouvez modifier les styles existants et supprimer, désactiver, réactiver, créer ou en importer de nouveaux. Vous pouvez également voir à quoi va ressembler un style en utilisant la fonction de prévisualisation. Le style actuellement par défaut est noté par la présence d’un astérisque (*). Vous pouvez aussi retrouver le compteur du nombre total d’utilisateurs de chaque style mais il est à noter que l’écrasement du style des utilisateurs ne sera pas répercuté dans cette comptabilisation.',
-	'ACP_TEMPLATES_EXPLAIN'	=> 'Un ensemble de templates comprend toutes les balises utilisées afin de générer l’aspect de votre forum. Vous pouvez éditer, supprimer, exporter, importer et prévisualiser ici ces ensembles. Vous pouvez également modifier le code des templates utilisés afin de générer du BBCode.',
-	'ACP_THEMES_EXPLAIN'	=> 'Vous pouvez créer, installer, éditer, supprimer et exporter ici des thèmes. Un thème est une combinaison de couleurs et d’images appliquée à vos templates afin de définir l’aspect basique de votre forum. La gamme des options disponibles dépend de la configuration de votre serveur et de l’installation de phpBB, veuillez consulter le manuel pour plus d’informations. Veuillez noter qu’en créant de nouveaux thèmes, l’utilisation d’un thème existant basique est optionnelle.',
+	'ACP_IMAGESETS_EXPLAIN'	=> 'Les ensembles d’images comprennent toutes les images de boutons, de forums, de répertoires, etc. Ils comprennent également d’autres images qui ne sont pas spécifiques au style utilisé sur le forum. Vous pouvez éditer, exporter ou supprimer sur cette page les ensembles d’images et en importer ou en activer de nouveaux.',
+	'ACP_STYLES_EXPLAIN'	=> 'Vous pouvez gérer sur cette page les styles disponibles sur votre forum. Un style comprend un ensemble de modèles, de thèmes et d’images. Vous pouvez modifier les styles existants et supprimer, désactiver, réactiver, créer ou en importer de nouveaux. Vous pouvez également voir à quoi va ressembler un style en utilisant la fonction de prévisualisation. Le style actuellement par défaut est noté par la présence d’un astérisque (*). Vous pouvez aussi retrouver le compteur du nombre total d’utilisateurs de chaque style mais il est à noter que l’écrasement du style des utilisateurs ne sera pas répercuté dans cette comptabilisation.',
+	'ACP_TEMPLATES_EXPLAIN'	=> 'Un ensemble de modèles comprend toutes les balises utilisées afin de générer l’aspect de votre forum. Vous pouvez éditer, supprimer, exporter, importer et prévisualiser sur cette page ces ensembles. Vous pouvez également modifier le code des modèles utilisés afin de générer du BBCode.',
+	'ACP_THEMES_EXPLAIN'	=> 'Vous pouvez créer, installer, éditer, supprimer et exporter sur cette page des thèmes. Un thème est une combinaison de couleurs et d’images appliquée à vos modèles afin de définir l’aspect basique de votre forum. La gamme des options disponibles dépend de la configuration de votre serveur et de l’installation de phpBB, veuillez consulter le manuel pour plus d’informations. Veuillez noter qu’en créant de nouveaux thèmes, l’utilisation d’un thème existant basique est optionnelle.',
 	'ADD_IMAGESET'			=> 'Créer un ensemble d’images',
-	'ADD_IMAGESET_EXPLAIN'	=> 'Vous pouvez créer ici un nouvel ensemble d’images. Des options additionnelles peuvent être présentes, selon la configuration de votre serveur et les permissions assignées aux fichiers. Par exemple, vous pourrez baser cet ensemble d’images sur un ensemble d’images qui existe déjà. Vous pourrez également envoyer ou importer un ensemble d’images depuis le répertoire de stockage.',
+	'ADD_IMAGESET_EXPLAIN'	=> 'Vous pouvez créer sur cette page un nouvel ensemble d’images. Des options additionnelles peuvent être présentes, selon la configuration de votre serveur et les permissions assignées aux fichiers. Par exemple, vous pourrez baser cet ensemble d’images sur un ensemble d’images qui existe déjà. Vous pourrez également envoyer ou importer un ensemble d’images depuis le répertoire de stockage.',
 	'ADD_STYLE'				=> 'Créer un style',
-	'ADD_STYLE_EXPLAIN'		=> 'Vous pouvez créer ici un nouveau style. Des options additionnelles peuvent être présentes, selon la configuration de votre serveur et les permissions assignées aux fichiers. Par exemple, vous pourrez baser ce style sur un style qui existe déjà. Vous pourrez également envoyer ou importer un ensemble de styles depuis le répertoire de stockage.',
-	'ADD_TEMPLATE'			=> 'Créer un template',
-	'ADD_TEMPLATE_EXPLAIN'	=> 'Vous pouvez ajouter ici un nouveau template. Des options additionnelles peuvent être présentes, selon la configuration de votre serveur et les permissions assignées aux fichiers. Par exemple, vous pourrez baser ce template sur un template qui existe déjà. Vous pourrez également envoyer ou importer un ensemble de templates depuis le répertoire de stockage.',
+	'ADD_STYLE_EXPLAIN'		=> 'Vous pouvez créer sur cette page un nouveau style. Des options additionnelles peuvent être présentes, selon la configuration de votre serveur et les permissions assignées aux fichiers. Par exemple, vous pourrez baser ce style sur un style qui existe déjà. Vous pourrez également envoyer ou importer un ensemble de styles depuis le répertoire de stockage.',
+	'ADD_TEMPLATE'			=> 'Créer un modèle',
+	'ADD_TEMPLATE_EXPLAIN'	=> 'Vous pouvez ajouter sur cette page un nouveau modèle. Des options additionnelles peuvent être présentes, selon la configuration de votre serveur et les permissions assignées aux fichiers. Par exemple, vous pourrez baser ce modèle sur un modèle qui existe déjà. Vous pourrez également envoyer ou importer un ensemble de modèles depuis le répertoire de stockage.',
 	'ADD_THEME'				=> 'Créer un thème',
-	'ADD_THEME_EXPLAIN'		=> 'Vous pouvez ajouter ici un nouveau thème. Des options additionnelles peuvent être présentes, selon la configuration de votre serveur et les permissions assignées aux fichiers. Par exemple, vous pourrez baser ce thème sur un thème qui existe déjà. Vous pourrez également envoyer ou importer un ensemble de thèmes depuis le répertoire de stockage.',
+	'ADD_THEME_EXPLAIN'		=> 'Vous pouvez ajouter sur cette page un nouveau thème. Des options additionnelles peuvent être présentes, selon la configuration de votre serveur et les permissions assignées aux fichiers. Par exemple, vous pourrez baser ce thème sur un thème qui existe déjà. Vous pourrez également envoyer ou importer un ensemble de thèmes depuis le répertoire de stockage.',
 	'ARCHIVE_FORMAT'		=> 'Format de l’archive',
 	'AUTOMATIC_EXPLAIN'		=> 'Laissez vide afin de tenter une détection automatique.',
 
@@ -59,61 +59,61 @@ $lang = array_merge($lang, array(
 
 	'CACHE'							=> 'Cache',
 	'CACHE_CACHED'					=> 'Mis en cache',
-	'CACHE_FILENAME'				=> 'Fichier template',
+	'CACHE_FILENAME'				=> 'Fichier modèle',
 	'CACHE_FILESIZE'				=> 'Taille du fichier',
 	'CACHE_MODIFIED'				=> 'Modifié',
 	'CONFIRM_IMAGESET_REFRESH'		=> 'Êtes-vous sûr(e) de vouloir rafraîchir toutes les données des ensembles d’images ? Cela écrasera toutes les modifications réalisées à partir de l’éditeur des ensembles d’images.',
-	'CONFIRM_TEMPLATE_CLEAR_CACHE'	=> 'Êtes-vous sûr(e) de vouloir supprimer toutes les versions des fichiers template mis en cache ?',
-	'CONFIRM_TEMPLATE_REFRESH'		=> 'Êtes-vous sûr(e) de vouloir rafraîchir toutes les données des templates stockés dans la base de données ? Cela écrasera toutes les modifications faites à partir de l’éditeur des templates stockés dans la base de données.',
+	'CONFIRM_TEMPLATE_CLEAR_CACHE'	=> 'Êtes-vous sûr(e) de vouloir supprimer toutes les versions des fichiers modèles mis en cache ?',
+	'CONFIRM_TEMPLATE_REFRESH'		=> 'Êtes-vous sûr(e) de vouloir rafraîchir toutes les données des modèles stockés dans la base de données ? Cela écrasera toutes les modifications faites à partir de l’éditeur des modèles stockés dans la base de données.',
 	'CONFIRM_THEME_REFRESH'			=> 'Êtes-vous sûr(e) de vouloir rafraîchir les données des thèmes stockés dans la base de données ? Ceci écrasera toutes modifications faites à partir de l’éditeur des thèmes stockés dans la base de données.',
-	'COPYRIGHT'						=> 'Copyright ',
+	'COPYRIGHT'						=> 'Copyright',
 	'CREATE_IMAGESET'				=> 'Créer un nouvel ensemble d’images',
 	'CREATE_STYLE'					=> 'Créer un nouveau style',
-	'CREATE_TEMPLATE'				=> 'Créer un nouvel ensemble de templates',
+	'CREATE_TEMPLATE'				=> 'Créer un nouvel ensemble de modèles',
 	'CREATE_THEME'					=> 'Créer un nouveau thème',
-	'CURRENT_IMAGE'					=> 'Image actuelle ',
+	'CURRENT_IMAGE'					=> 'Image actuelle',
 
 	'DEACTIVATE_DEFAULT'		=> 'Vous ne pouvez pas désactiver le style par défaut.',
 	'DELETE_FROM_FS'			=> 'Supprimer du système de fichiers',
 	'DELETE_IMAGESET'			=> 'Supprimer l’ensemble d’images',
-	'DELETE_IMAGESET_EXPLAIN'	=> 'Vous pouvez supprimer ici l’ensemble d’images que vous avez sélectionné. Veuillez noter que cette opération est irréversible. Il est donc recommandé d’effectuer une sauvegarde de votre ensemble d’images pour une possible utilisation future.',
+	'DELETE_IMAGESET_EXPLAIN'	=> 'Vous pouvez supprimer sur cette page l’ensemble d’images que vous avez sélectionné. Veuillez noter que cette opération est irréversible. Il est donc recommandé d’effectuer une sauvegarde de votre ensemble d’images pour une possible utilisation future.',
 	'DELETE_STYLE'				=> 'Supprimer le style',
-	'DELETE_STYLE_EXPLAIN'		=> 'Vous pouvez supprimer ici le style que vous avez sélectionné. Soyez prudent lorsque vous supprimez des styles car cette opération est irréversible.',
-	'DELETE_TEMPLATE'			=> 'Supprimer l’ensemble de templates',
-	'DELETE_TEMPLATE_EXPLAIN'	=> 'Vous pouvez supprimer ici l’ensemble de templates que vous avez sélectionné de la base de données. Veuillez noter que cette opération est irréversible. Il est donc recommandé d’effectuer une sauvegarde de votre ensemble de templates pour une possible utilisation future.',
+	'DELETE_STYLE_EXPLAIN'		=> 'Vous pouvez supprimer sur cette page le style que vous avez sélectionné. Soyez prudent lorsque vous supprimez des styles car cette opération est irréversible.',
+	'DELETE_TEMPLATE'			=> 'Supprimer l’ensemble de modèles',
+	'DELETE_TEMPLATE_EXPLAIN'	=> 'Vous pouvez supprimer sur cette page l’ensemble de modèles que vous avez sélectionné de la base de données. Veuillez noter que cette opération est irréversible. Il est donc recommandé d’effectuer une sauvegarde de votre ensemble de modèles pour une possible utilisation future.',
 	'DELETE_THEME'				=> 'Supprimer le thème',
-	'DELETE_THEME_EXPLAIN'		=> 'Vous pouvez supprimer ici le thème que vous avez sélectionné de la base de données. Veuillez noter que cette opération est irréversible. Il est donc recommandé d’effectuer une sauvegarde de votre thème pour une possible utilisation future.',
+	'DELETE_THEME_EXPLAIN'		=> 'Vous pouvez supprimer sur cette page le thème que vous avez sélectionné de la base de données. Veuillez noter que cette opération est irréversible. Il est donc recommandé d’effectuer une sauvegarde de votre thème pour une possible utilisation future.',
 	'DETAILS'					=> 'Informations',
 	'DIMENSIONS_EXPLAIN'		=> 'Si vous sélectionnez « Oui » ici, cela inclura les paramètres de largeur et de hauteur.',
 
 
 	'EDIT_DETAILS_IMAGESET'				=> 'Éditer les informations de l’ensemble d’images',
-	'EDIT_DETAILS_IMAGESET_EXPLAIN'		=> 'Vous pouvez éditer ici certaines informations de l’ensemble d’images, tel que son nom.',
+	'EDIT_DETAILS_IMAGESET_EXPLAIN'		=> 'Vous pouvez éditer sur cette page certaines informations de l’ensemble d’images, tel que son nom.',
 	'EDIT_DETAILS_STYLE'				=> 'Éditer un style',
-	'EDIT_DETAILS_STYLE_EXPLAIN'		=> 'En utilisant le formulaire ci-dessous, vous pouvez modifier ce style. Vous pouvez modifier sa combinaison de template, de thème et d’ensemble d’images qui définit le style en lui-même. Vous pouvez également définir le style comme étant celui à utiliser par défaut.',
-	'EDIT_DETAILS_TEMPLATE'				=> 'Éditer les informations du template',
-	'EDIT_DETAILS_TEMPLATE_EXPLAIN'		=> 'Vous pouvez éditer ici certaines informations du template, tel que son nom. Vous pouvez également avoir l’option qui vous permet de basculer le stockage de la feuille de style du système de fichiers à la base de données, et vice et versa. Cette option dépend de la configuration de PHP et de votre serveur.',
+	'EDIT_DETAILS_STYLE_EXPLAIN'		=> 'En utilisant le formulaire ci-dessous, vous pouvez modifier ce style. Vous pouvez modifier sa combinaison de modèle, de thème et d’ensemble d’images qui définit le style en lui-même. Vous pouvez également définir le style comme étant celui à utiliser par défaut.',
+	'EDIT_DETAILS_TEMPLATE'				=> 'Éditer les informations du modèle',
+	'EDIT_DETAILS_TEMPLATE_EXPLAIN'		=> 'Vous pouvez éditer sur cette page certaines informations du modèle, tel que son nom. Vous pouvez également avoir l’option qui vous permet de basculer le stockage de la feuille de style du système de fichiers à la base de données, et vice et versa. Cette option dépend de la configuration de PHP et de votre serveur.',
 	'EDIT_DETAILS_THEME'				=> 'Éditer les informations du thème',
-	'EDIT_DETAILS_THEME_EXPLAIN'		=> 'Vous pouvez éditer ici les informations du thème, tel que son nom. Vous pouvez également avoir l’option qui vous permet de basculer le stockage de la feuille de style du système de fichiers à la base de données, et vice et versa. Cette option dépend de la configuration de PHP et de votre serveur.',
+	'EDIT_DETAILS_THEME_EXPLAIN'		=> 'Vous pouvez éditer sur cette page les informations du thème, tel que son nom. Vous pouvez également avoir l’option qui vous permet de basculer le stockage de la feuille de style du système de fichiers à la base de données, et vice et versa. Cette option dépend de la configuration de PHP et de votre serveur.',
 	'EDIT_IMAGESET'						=> 'Éditer un ensemble d’images',
-	'EDIT_IMAGESET_EXPLAIN'				=> 'Vous pouvez éditer ici les images individuelles qui définissent l’ensemble d’images. Vous pouvez également spécifier les dimensions de l’image. Elles sont optionnelles mais peuvent aider à résoudre certains problèmes graphiques rencontrés avec quelques navigateurs. Cependant, si vous ne les spécifiez pas, cela permettra de réduire la taille de la base de données.',
-	'EDIT_TEMPLATE'						=> 'Éditer un ensemble de templates',
-	'EDIT_TEMPLATE_EXPLAIN'				=> 'Vous pouvez éditer ici votre ensemble de templates. Veuillez noter que ces éditions sont permanentes et qu’elles ne peuvent pas être annulées une fois effectuées. Si PHP arrive à écrire dans vos fichiers de templates situés dans le répertoire de vos styles, toutes les modifications seront directement écrites dans ces fichiers. Si PHP n’arrive pas à écrire dans ces fichiers, ils seront alors copiés dans la base de données et toute modification ne sera reflétée qu’ici. Soyez prudent en éditant votre ensemble de templates et n’oubliez pas de fermer tous les termes de remplacement de variables {XXXX} et les rapports conditionnels.',
-	'EDIT_TEMPLATE_STORED_DB'			=> 'Le fichier template n’a pas pu être écrit. L’ensemble de templates est à présent stocké dans la base de données et contient le fichier modifié.',
+	'EDIT_IMAGESET_EXPLAIN'				=> 'Vous pouvez éditer sur cette page les images individuelles qui définissent l’ensemble d’images. Vous pouvez également spécifier les dimensions de l’image. Elles sont optionnelles mais peuvent aider à résoudre certains problèmes graphiques rencontrés avec quelques navigateurs. Cependant, si vous ne les spécifiez pas, cela permettra de réduire la taille de la base de données.',
+	'EDIT_TEMPLATE'						=> 'Éditer un ensemble de modèles',
+	'EDIT_TEMPLATE_EXPLAIN'				=> 'Vous pouvez éditer sur cette page votre ensemble de modèles. Veuillez noter que ces éditions sont permanentes et qu’elles ne peuvent pas être annulées une fois effectuées. Si PHP arrive à écrire dans vos fichiers de modèles situés dans le répertoire de vos styles, toutes les modifications seront directement écrites dans ces fichiers. Si PHP n’arrive pas à écrire dans ces fichiers, ils seront alors copiés dans la base de données et toute modification ne sera reflétée qu’ici. Soyez prudent en éditant votre ensemble de modèles et n’oubliez pas de fermer tous les termes de remplacement de variables {XXXX} et les rapports conditionnels.',
+	'EDIT_TEMPLATE_STORED_DB'			=> 'Le fichier modèle n’a pas pu être écrit. L’ensemble de modèles est à présent stocké dans la base de données et contient le fichier modifié.',
 	'EDIT_THEME'						=> 'Éditer un thème',
-	'EDIT_THEME_EXPLAIN'				=> 'Vous pouvez éditer ici le thème que vous avez sélectionné en modifiant ses couleurs, ses images, etc.',
+	'EDIT_THEME_EXPLAIN'				=> 'Vous pouvez éditer sur cette page le thème que vous avez sélectionné en modifiant ses couleurs, ses images, etc.',
 	'EDIT_THEME_STORED_DB'				=> 'La feuille de style n’a pas pu être écrite. Elle est à présent stockée dans la base de données et contient votre modification.',
 	'EDIT_THEME_STORE_PARSED'			=> 'Le thème requiert que sa feuille de style soit analysée. Ceci n’est possible que si cette dernière est stockée dans la base de données.',
-	'EDITOR_DISABLED'               => 'L’éditeur de templates est désactivé.',
+	'EDITOR_DISABLED'               => 'L’éditeur de modèles est désactivé.',
 	'EXPORT'							=> 'Exporter',
 
 	'FOREGROUND'			=> 'Premier plan',
 	'FONT_COLOUR'			=> 'Couleur de la police de caractères',
 	'FONT_FACE'				=> 'Police',
 	'FONT_FACE_EXPLAIN'		=> 'Vous pouvez spécifier plusieurs polices de caractères en les séparant par une virgule. Si un utilisateur n’a pas la première police de caractères installée sur son ordinateur, la suivante sera alors sélectionnée.',
-	'FONT_SIZE'				=> 'Taille de la police de caractères ',
+	'FONT_SIZE'				=> 'Taille de la police de caractères',
 
-	'GLOBAL_IMAGES'			=> 'Globales',
+	'GLOBAL_IMAGES'			=> 'Générales',
 
 	'HIDE_CSS'				=> 'Masquer le CSS brut',
 
@@ -136,7 +136,7 @@ $lang = array_merge($lang, array(
 	'IMAGESET_ERR_NOT_IMAGESET'	=> 'Le fichier compressé que vous avez spécifié ne contient pas d’ensemble d’images correct.',
 	'IMAGESET_ERR_STYLE_NAME'	=> 'Vous devez spécifier le nom de cet ensemble d’images.',
 	'IMAGESET_EXPORT'			=> 'Exporter un ensemble d’images',
-	'IMAGESET_EXPORT_EXPLAIN'	=> 'Vous pouvez exporter ici un ensemble d’images sous forme de fichier compressé. Ce dernier contiendra toutes les données nécessaires afin d’installer l’ensemble d’images sur un autre forum. Vous pouvez soit télécharger le fichier directement, soit le placer dans votre dossier de stockage afin de le télécharger ultérieurement par FTP.',
+	'IMAGESET_EXPORT_EXPLAIN'	=> 'Vous pouvez exporter sur cette page un ensemble d’images sous forme de fichier compressé. Ce dernier contiendra toutes les données nécessaires afin d’installer l’ensemble d’images sur un autre forum. Vous pouvez soit télécharger le fichier directement, soit le placer dans votre dossier de stockage afin de le télécharger ultérieurement par FTP.',
 	'IMAGESET_EXPORTED'			=> 'L’ensemble d’images a été exporté et stocké dans %s.',
 	'IMAGESET_NAME'				=> 'Nom de l’ensemble d’images',
 	'IMAGESET_REFRESHED'		=> 'L’ensemble d’images a été rafraîchi.',
@@ -205,14 +205,14 @@ $lang = array_merge($lang, array(
 	'IMG_ANNOUNCE_UNREAD_LOCKED'		=> 'Annonce verrouillée contenant des messages non lus',
 	'IMG_ANNOUNCE_UNREAD_LOCKED_MINE'	=> 'Annonce verrouillée et pointée contenant des messages non lus',
 
-	'IMG_GLOBAL_READ'					=> 'Annonce globale',
-	'IMG_GLOBAL_READ_MINE'				=> 'Annonce globale pointée',
-	'IMG_GLOBAL_READ_LOCKED'			=> 'Annonce globale verrouillée',
-	'IMG_GLOBAL_READ_LOCKED_MINE'		=> 'Annonce globale verrouillée et pointée',
-	'IMG_GLOBAL_UNREAD'					=> 'Annonce globale contenant des messages non lus',
-	'IMG_GLOBAL_UNREAD_MINE'			=> 'Annonce globale pointée contenant des messages non lus',
-	'IMG_GLOBAL_UNREAD_LOCKED'			=> 'Annonce globale verrouillée contenant des messages non lus',
-	'IMG_GLOBAL_UNREAD_LOCKED_MINE'		=> 'Annonce globale verrouillée et pointée contenant des messages non lus',
+	'IMG_GLOBAL_READ'					=> 'Annonce générale',
+	'IMG_GLOBAL_READ_MINE'				=> 'Annonce générale pointée',
+	'IMG_GLOBAL_READ_LOCKED'			=> 'Annonce générale verrouillée',
+	'IMG_GLOBAL_READ_LOCKED_MINE'		=> 'Annonce générale verrouillée et pointée',
+	'IMG_GLOBAL_UNREAD'					=> 'Annonce générale contenant des messages non lus',
+	'IMG_GLOBAL_UNREAD_MINE'			=> 'Annonce générale pointée contenant des messages non lus',
+	'IMG_GLOBAL_UNREAD_LOCKED'			=> 'Annonce générale verrouillée contenant des messages non lus',
+	'IMG_GLOBAL_UNREAD_LOCKED_MINE'		=> 'Annonce générale verrouillée et pointée contenant des messages non lus',
 
 	'IMG_PM_READ'		=> 'Message privé lu',
 	'IMG_PM_UNREAD'		=> 'Message privé non lu',
@@ -220,7 +220,7 @@ $lang = array_merge($lang, array(
 	'IMG_ICON_BACK_TOP'		=> 'Haut',
 
 	'IMG_ICON_CONTACT_AIM'		=> 'AIM',
-	'IMG_ICON_CONTACT_EMAIL'	=> 'Envoyer un courriel',
+	'IMG_ICON_CONTACT_EMAIL'	=> 'Envoyer un courrier électronique',
 	'IMG_ICON_CONTACT_ICQ'		=> 'ICQ',
 	'IMG_ICON_CONTACT_JABBER'	=> 'Jabber',
 	'IMG_ICON_CONTACT_MSNM'		=> 'MSNM',
@@ -270,24 +270,24 @@ $lang = array_merge($lang, array(
 	'INACTIVE_STYLES'			=> 'Styles inactifs',
 	'INCLUDE_DIMENSIONS'		=> 'Inclure les dimensions',
 	'INCLUDE_IMAGESET'			=> 'Inclure l’ensemble d’images',
-	'INCLUDE_TEMPLATE'			=> 'Inclure le template',
+	'INCLUDE_TEMPLATE'			=> 'Inclure le modèle',
 	'INCLUDE_THEME'				=> 'Inclure le thème',
-	'INHERITING_FROM'         => 'Hérite de ',
+	'INHERITING_FROM'         => 'Hérite de',
 	'INSTALL_IMAGESET'			=> 'Installer un ensemble d’images',
-	'INSTALL_IMAGESET_EXPLAIN'	=> 'Vous pouvez installer ici un ensemble d’images. Si vous le souhaitez, vous pouvez éditer certaines informations ou utiliser les valeurs par défaut lors de l’installation.',
+	'INSTALL_IMAGESET_EXPLAIN'	=> 'Vous pouvez installer sur cette page un ensemble d’images. Si vous le souhaitez, vous pouvez éditer certaines informations ou utiliser les valeurs par défaut lors de l’installation.',
 	'INSTALL_STYLE'				=> 'Installer un style',
-	'INSTALL_STYLE_EXPLAIN'		=> 'Vous pouvez installer ici un style et ses éléments. Si les éléments appropriés au style sont déjà installés, ils ne seront pas écrasés. Certains styles nécessitent que ces éléments soient déjà installés. Si vous en rencontrez un de ce genre, vous en serez alors informé(e).',
-	'INSTALL_TEMPLATE'			=> 'Installer un ensemble de templates',
-	'INSTALL_TEMPLATE_EXPLAIN'	=> 'Vous pouvez installer ici un ensemble de templates. Selon la configuration de votre serveur, vous pouvez rencontrer certaines options supplémentaires.',
+	'INSTALL_STYLE_EXPLAIN'		=> 'Vous pouvez installer sur cette page un style et ses éléments. Si les éléments appropriés au style sont déjà installés, ils ne seront pas écrasés. Certains styles nécessitent que ces éléments soient déjà installés. Si vous en rencontrez un de ce genre, vous en serez alors informé(e).',
+	'INSTALL_TEMPLATE'			=> 'Installer un ensemble de modèles',
+	'INSTALL_TEMPLATE_EXPLAIN'	=> 'Vous pouvez installer sur cette page un ensemble de modèles. Selon la configuration de votre serveur, vous pouvez rencontrer certaines options supplémentaires.',
 	'INSTALL_THEME'				=> 'Installer un thème',
-	'INSTALL_THEME_EXPLAIN'		=> 'Vous pouvez installer ici un thème. Si vous le souhaitez, vous pouvez éditer certaines informations ou utiliser les valeurs par défaut lors de l’installation.',
+	'INSTALL_THEME_EXPLAIN'		=> 'Vous pouvez installer sur cette page un thème. Si vous le souhaitez, vous pouvez éditer certaines informations ou utiliser les valeurs par défaut lors de l’installation.',
 	'INSTALLED_IMAGESET'		=> 'Ensembles d’images installés',
 	'INSTALLED_STYLE'			=> 'Styles installés',
-	'INSTALLED_TEMPLATE'		=> 'Ensembles de templates installés',
+	'INSTALLED_TEMPLATE'		=> 'Ensembles de modèles installés',
 	'INSTALLED_THEME'			=> 'Thèmes installés',
 
 	'KEEP_IMAGESET'				=> 'Conserver l’ensemble d’images « %s »',
-	'KEEP_TEMPLATE'				=> 'Conserver le template « %s »',
+	'KEEP_TEMPLATE'				=> 'Conserver le modèle « %s »',
 	'KEEP_THEME'				=> 'Conserver le thème « %s »',
 
 	'LINE_SPACING'				=> 'Ligne d’espacement',
@@ -299,17 +299,17 @@ $lang = array_merge($lang, array(
 	'NO_IMAGE'					=> 'Aucune image',
 	'NO_IMAGE_ERROR'			=> 'Aucune image n’a été trouvée dans le système de fichiers.',
 	'NO_STYLE'					=> 'Aucun style n’a été trouvé dans le système de fichiers.',
-	'NO_TEMPLATE'				=> 'Aucun ensemble de templates n’a été trouvé dans le système de fichiers.',
+	'NO_TEMPLATE'				=> 'Aucun ensemble de modèles n’a été trouvé dans le système de fichiers.',
 	'NO_THEME'					=> 'Aucun thème n’a été trouvé dans le système de fichiers.',
 	'NO_UNINSTALLED_IMAGESET'	=> 'Aucun ensemble d’images désinstallé n’a été détecté.',
 	'NO_UNINSTALLED_STYLE'		=> 'Aucun style désinstallé n’a été détecté.',
-	'NO_UNINSTALLED_TEMPLATE'	=> 'Aucun ensemble de templates désinstallé n’a été détecté.',
+	'NO_UNINSTALLED_TEMPLATE'	=> 'Aucun ensemble de modèles désinstallé n’a été détecté.',
 	'NO_UNINSTALLED_THEME'		=> 'Aucun thème désinstallé n’a été détecté.',
 	'NO_UNIT'					=> 'Aucun',
 
 	'ONLY_IMAGESET'			=> 'Ceci est le seul ensemble d’images restant, vous ne pouvez pas l’effacer.',
 	'ONLY_STYLE'			=> 'Ceci est le seul style restant, vous ne pouvez pas l’effacer.',
-	'ONLY_TEMPLATE'			=> 'Ceci est le seul ensemble de templates restant, vous ne pouvez pas l’effacer.',
+	'ONLY_TEMPLATE'			=> 'Ceci est le seul ensemble de modèles restant, vous ne pouvez pas l’effacer.',
 	'ONLY_THEME'			=> 'Ceci est le seul thème restant, vous ne pouvez pas l’effacer.',
 	'OPTIONAL_BASIS'		=> 'Base optionnelle',
 
@@ -322,31 +322,31 @@ $lang = array_merge($lang, array(
 	'REPLACE_IMAGESET_EXPLAIN'	=> 'Cet ensemble d’images remplacera celui que vous supprimez dans tous les styles l’utilisant.',
 	'REPLACE_STYLE'				=> 'Remplacer le style par',
 	'REPLACE_STYLE_EXPLAIN'		=> 'Ce style remplacera celui qui a été supprimé pour les membres l’utilisant.',
-	'REPLACE_TEMPLATE'			=> 'Remplacer l’ensemble de templates par',
-	'REPLACE_TEMPLATE_EXPLAIN'	=> 'Cet ensemble de templates remplacera celui que vous supprimez dans tous les styles l’utilisant.',
+	'REPLACE_TEMPLATE'			=> 'Remplacer l’ensemble de modèles par',
+	'REPLACE_TEMPLATE_EXPLAIN'	=> 'Cet ensemble de modèles remplacera celui que vous supprimez dans tous les styles l’utilisant.',
 	'REPLACE_THEME'				=> 'Remplacer le thème par',
 	'REPLACE_THEME_EXPLAIN'		=> 'Ce thème remplacera celui que vous supprimez dans tous les styles l’utilisant.',
 	'REPLACE_WITH_OPTION'		=> 'Remplacer par « %s »',
 	'REQUIRES_IMAGESET'			=> 'Ce style requiert l’installation de l’ensemble d’images %s.',
-	'REQUIRES_TEMPLATE'			=> 'Ce style requiert l’installation de l’ensemble de templates %s.',
+	'REQUIRES_TEMPLATE'			=> 'Ce style requiert l’installation de l’ensemble de modèles %s.',
 	'REQUIRES_THEME'			=> 'Ce style requiert l’installation du thème %s.',
 
 	'SELECT_IMAGE'				=> 'Sélectionner l’image',
-	'SELECT_TEMPLATE'			=> 'Sélectionner le fichier template',
+	'SELECT_TEMPLATE'			=> 'Sélectionner le fichier modèle',
 	'SELECT_THEME'				=> 'Sélectionner le fichier thème',
 	'SELECTED_IMAGE'			=> 'Image sélectionnée',
 	'SELECTED_IMAGESET'			=> 'Ensemble d’images sélectionné',
-	'SELECTED_TEMPLATE'			=> 'Template sélectionné',
-	'SELECTED_TEMPLATE_FILE'	=> 'Fichier template sélectionné',
+	'SELECTED_TEMPLATE'			=> 'Modèle sélectionné',
+	'SELECTED_TEMPLATE_FILE'	=> 'Fichier modèle sélectionné',
 	'SELECTED_THEME'			=> 'Thème sélectionné',
 	'SELECTED_THEME_FILE'		=> 'Fichier thème sélectionné',
 	'STORE_DATABASE'			=> 'Base de données',
 	'STORE_FILESYSTEM'			=> 'Système de fichiers',
 	'STYLE_ACTIVATE'			=> 'Activer',
-	'STYLE_ACTIVE'				=> 'Actif ',
+	'STYLE_ACTIVE'				=> 'Actif',
 	'STYLE_ADDED'				=> 'Le style a été ajouté.',
 	'STYLE_DEACTIVATE'			=> 'Désactiver',
-	'STYLE_DEFAULT'				=> 'En faire le style par défaut ',
+	'STYLE_DEFAULT'				=> 'En faire le style par défaut',
 	'STYLE_DELETED'				=> 'Le style a été supprimé.',
 	'STYLE_DETAILS_UPDATED'		=> 'Le style a été édité.',
 	'STYLE_ERR_ARCHIVE'			=> 'Veuillez sélectionner une méthode de compression.',
@@ -355,50 +355,50 @@ $lang = array_merge($lang, array(
 	'STYLE_ERR_NAME_CHARS'		=> 'Le nom du style ne doit contenir que des lettres, des chiffres, des tirets, des plus, des tirets bas et des espaces.',
 	'STYLE_ERR_NAME_EXIST'		=> 'Un style portant ce nom existe déjà.',
 	'STYLE_ERR_NAME_LONG'		=> 'Le nom du style ne doit pas dépasser 30 caractères.',
-	'STYLE_ERR_NO_IDS'			=> 'Vous devez sélectionner un template, un thème et un ensemble d’images pour ce style.',
+	'STYLE_ERR_NO_IDS'			=> 'Vous devez sélectionner un modèle, un thème et un ensemble d’images pour ce style.',
 	'STYLE_ERR_NOT_STYLE'		=> 'Le fichier importé ou transféré ne contient pas de fichier de style compressé correct.',
 	'STYLE_ERR_STYLE_NAME'		=> 'Vous devez spécifier le nom de ce style.',
 	'STYLE_EXPORT'				=> 'Exporter un style',
-	'STYLE_EXPORT_EXPLAIN'		=> 'Vous pouvez exporter ici un style sous forme de fichier compressé. Un style ne devra pas contenir tous les éléments, mais il doit en contenir au moins un. Par exemple, si vous créez un nouveau thème et un ensemble d’images pour un template fréquemment utilisé, vous pourriez simplement exporter le thème et l’ensemble d’images, en omettant le template. Vous pouvez soit télécharger le dossier directement, soit le placer dans votre répertoire de stockage afin de le télécharger ultérieurement par FTP.',
+	'STYLE_EXPORT_EXPLAIN'		=> 'Vous pouvez exporter sur cette page un style sous forme de fichier compressé. Un style ne devra pas contenir tous les éléments, mais il doit en contenir au moins un. Par exemple, si vous créez un nouveau thème et un ensemble d’images pour un modèle fréquemment utilisé, vous pourriez simplement exporter le thème et l’ensemble d’images, en omettant le modèle. Vous pouvez soit télécharger le dossier directement, soit le placer dans votre répertoire de stockage afin de le télécharger ultérieurement par FTP.',
 	'STYLE_EXPORTED'			=> 'Le style a été exporté et stocké dans %s.',
 	'STYLE_IMAGESET'			=> 'Ensemble d’images',
-	'STYLE_NAME'				=> 'Nom du style ',
-	'STYLE_TEMPLATE'			=> 'Template',
+	'STYLE_NAME'				=> 'Nom du style',
+	'STYLE_TEMPLATE'			=> 'Modèle',
 	'STYLE_THEME'				=> 'Thème',
 	'STYLE_USED_BY'				=> 'Utilisé par (en incluant les robots)',
 
-	'TEMPLATE_ADDED'			=> 'L’ensemble de templates a été ajouté au système de fichiers.',
-	'TEMPLATE_ADDED_DB'			=> 'L’ensemble de templates a été ajouté à la base de données.',
-	'TEMPLATE_CACHE'			=> 'Cache du template',
-	'TEMPLATE_CACHE_EXPLAIN'	=> 'Par défaut, phpBB met en cache la version compilée de ses templates. Cela permet de diminuer la charge du serveur à chaque fois qu’une page est consultée et réduit le temps de chargement de la page. Vous pouvez consulter ici le statut en cache de chaque fichier et supprimer individuellement les fichiers ou le cache en entier.',
-	'TEMPLATE_CACHE_CLEARED'	=> 'Le cache du template a été vidé.',
-	'TEMPLATE_CACHE_EMPTY'		=> 'Il n’y a aucun template mis en cache.',
-	'TEMPLATE_DELETED'			=> 'L’ensemble de templates a été supprimé.',
-	'TEMPLATE_DELETE_DEPENDENT'   => 'L’ensemble de templates ne peut être supprimé car un ou plusieurs autres templates héritent de ce dernier :',
-	'TEMPLATE_DELETED_FS'		=> 'L’ensemble de templates a été supprimé de la base données mais certains fichiers ont été conservés dans le système de fichiers.',
-	'TEMPLATE_DETAILS_UPDATED'	=> 'Les informations concernant l’ensemble de templates ont été mises à jour.',
-	'TEMPLATE_EDITOR'			=> 'Éditeur de templates en HTML brut',
-	'TEMPLATE_EDITOR_HEIGHT'	=> 'Taille de l’éditeur de templates',
+	'TEMPLATE_ADDED'			=> 'L’ensemble de modèles a été ajouté au système de fichiers.',
+	'TEMPLATE_ADDED_DB'			=> 'L’ensemble de modèles a été ajouté à la base de données.',
+	'TEMPLATE_CACHE'			=> 'Cache du modèle',
+	'TEMPLATE_CACHE_EXPLAIN'	=> 'Par défaut, phpBB met en cache la version compilée de ses modèles. Cela permet de diminuer la charge du serveur à chaque fois qu’une page est consultée et réduit le temps de chargement de la page. Vous pouvez consulter ici le statut en cache de chaque fichier et supprimer individuellement les fichiers ou le cache en entier.',
+	'TEMPLATE_CACHE_CLEARED'	=> 'Le cache du modèle a été vidé.',
+	'TEMPLATE_CACHE_EMPTY'		=> 'Il n’y a aucun modèle mis en cache.',
+	'TEMPLATE_DELETED'			=> 'L’ensemble de modèles a été supprimé.',
+	'TEMPLATE_DELETE_DEPENDENT'   => 'L’ensemble de modèles ne peut être supprimé car un ou plusieurs autres modèles héritent de ce dernier :',
+	'TEMPLATE_DELETED_FS'		=> 'L’ensemble de modèles a été supprimé de la base données mais certains fichiers ont été conservés dans le système de fichiers.',
+	'TEMPLATE_DETAILS_UPDATED'	=> 'Les informations concernant l’ensemble de modèles ont été mises à jour.',
+	'TEMPLATE_EDITOR'			=> 'Éditeur de modèles en HTML brut',
+	'TEMPLATE_EDITOR_HEIGHT'	=> 'Taille de l’éditeur de modèles',
 	'TEMPLATE_ERR_ARCHIVE'		=> 'Veuillez sélectionner une méthode de compression.',
-	'TEMPLATE_ERR_CACHE_READ'	=> 'Le répertoire de cache utilisé afin de stocker les versions des fichiers de templates mis en cache ne peut pas être lu.',
+	'TEMPLATE_ERR_CACHE_READ'	=> 'Le répertoire de cache utilisé afin de stocker les versions des fichiers de modèles mis en cache ne peut pas être lu.',
 	'TEMPLATE_ERR_COPY_LONG'	=> 'Le copyright ne doit pas dépasser 60 caractères.',
-	'TEMPLATE_ERR_NAME_CHARS'	=> 'Le nom de l’ensemble de templates ne doit contenir que des lettres, des chiffres, des tirets, des plus, des tirets bas et des espaces.',
-	'TEMPLATE_ERR_NAME_EXIST'	=> 'Un ensemble de templates portant ce nom existe déjà.',
-	'TEMPLATE_ERR_NAME_LONG'	=> 'Le nom de l’ensemble de templates ne doit pas dépasser 30 caractères.',
-	'TEMPLATE_ERR_NOT_TEMPLATE'	=> 'Le fichier compressé que vous avez spécifié ne contient aucun ensemble de templates correct.',
-	'TEMPLATE_ERR_REQUIRED_OR_INCOMPLETE' => 'Le nouvel ensemble de templates requiert l’installation du template %s et ne doit pas hériter de ce dernier.',
-	'TEMPLATE_ERR_STYLE_NAME'	=> 'Vous devez spécifier le nom de cet ensemble de templates.',
-	'TEMPLATE_EXPORT'			=> 'Exporter un ensemble de templates',
-	'TEMPLATE_EXPORT_EXPLAIN'	=> 'Vous pouvez exporter ici un ensemble de templates sous forme de fichier compressé. Le fichier compressé ne devra pas contenir tous les fichiers nécessaires à l’installation de templates sur un autre forum. Vous pouvez soit télécharger le dossier directement, soit le placer dans votre répertoire de stockage afin de le télécharger ultérieurement par FTP.',
-	'TEMPLATE_EXPORTED'			=> 'Les templates ont été exportés et stockés dans %s.',
-	'TEMPLATE_FILE'				=> 'Fichier template',
-	'TEMPLATE_FILE_UPDATED'		=> 'Le fichier template a été mis à jour.',
-	'TEMPLATE_INHERITS'         => 'Ces ensembles de templates héritent de %s et ne peuvent donc pas avoir de réglages de stockage différents à ceux du super template.',
-	'TEMPLATE_LOCATION'			=> 'Stocker les templates dans',
+	'TEMPLATE_ERR_NAME_CHARS'	=> 'Le nom de l’ensemble de modèles ne doit contenir que des lettres, des chiffres, des tirets, des plus, des tirets bas et des espaces.',
+	'TEMPLATE_ERR_NAME_EXIST'	=> 'Un ensemble de modèles portant ce nom existe déjà.',
+	'TEMPLATE_ERR_NAME_LONG'	=> 'Le nom de l’ensemble de modèles ne doit pas dépasser 30 caractères.',
+	'TEMPLATE_ERR_NOT_TEMPLATE'	=> 'Le fichier compressé que vous avez spécifié ne contient aucun ensemble de modèles correct.',
+	'TEMPLATE_ERR_REQUIRED_OR_INCOMPLETE' => 'Le nouvel ensemble de modèles requiert l’installation du modèle %s et ne doit pas hériter de ce dernier.',
+	'TEMPLATE_ERR_STYLE_NAME'	=> 'Vous devez spécifier le nom de cet ensemble de modèles.',
+	'TEMPLATE_EXPORT'			=> 'Exporter un ensemble de modèles',
+	'TEMPLATE_EXPORT_EXPLAIN'	=> 'Vous pouvez exporter sur cette page un ensemble de modèles sous forme de fichier compressé. Le fichier compressé ne devra pas contenir tous les fichiers nécessaires à l’installation de modèles sur un autre forum. Vous pouvez soit télécharger le dossier directement, soit le placer dans votre répertoire de stockage afin de le télécharger ultérieurement par FTP.',
+	'TEMPLATE_EXPORTED'			=> 'Les modèles ont été exportés et stockés dans %s.',
+	'TEMPLATE_FILE'				=> 'Fichier modèle',
+	'TEMPLATE_FILE_UPDATED'		=> 'Le fichier modèle a été mis à jour.',
+	'TEMPLATE_INHERITS'         => 'Ces ensembles de modèles héritent de %s et ne peuvent donc pas avoir de réglages de stockage différents à ceux du super modèle.',
+	'TEMPLATE_LOCATION'			=> 'Stocker les modèles dans',
 	'TEMPLATE_LOCATION_EXPLAIN'	=> 'Les images sont toujours stockées dans le système de fichiers.',
-	'TEMPLATE_NAME'				=> 'Nom du template',
-	'TEMPLATE_FILE_NOT_WRITABLE'=> 'Impossible d’écrire sur le fichier template %s. Veuillez vérifier les permissions du répertoire et des fichiers.',
-	'TEMPLATE_REFRESHED'		=> 'Le template a été rafraîchi.',
+	'TEMPLATE_NAME'				=> 'Nom du modèle',
+	'TEMPLATE_FILE_NOT_WRITABLE'=> 'Impossible d’écrire sur le fichier modèle %s. Veuillez vérifier les permissions du répertoire et des fichiers.',
+	'TEMPLATE_REFRESHED'		=> 'Le modèle a été rafraîchi.',
 
 	'THEME_ADDED'				=> 'Le thème a été ajouté au système de fichiers.',
 	'THEME_ADDED_DB'			=> 'Le thème a été ajouté à la base de données.',
@@ -419,7 +419,7 @@ $lang = array_merge($lang, array(
 	'THEME_ERR_STYLE_NAME'		=> 'Vous devez spécifier le nom de ce thème.',
 	'THEME_FILE'				=> 'Fichier thème',
 	'THEME_EXPORT'				=> 'Exporter un thème',
-	'THEME_EXPORT_EXPLAIN'		=> 'Vous pouvez exporter ici un thème sous forme de fichier compressé. Ce fichier compressé contiendra toutes les données nécessaires à l’installation du thème sur un autre forum. Vous pouvez soit télécharger le fichier directement, soit le placer dans votre répertoire de stockage afin de le télécharger ultérieurement par FTP.',
+	'THEME_EXPORT_EXPLAIN'		=> 'Vous pouvez exporter sur cette page un thème sous forme de fichier compressé. Ce fichier compressé contiendra toutes les données nécessaires à l’installation du thème sur un autre forum. Vous pouvez soit télécharger le fichier directement, soit le placer dans votre répertoire de stockage afin de le télécharger ultérieurement par FTP.',
 	'THEME_EXPORTED'			=> 'Le thème a été exporté et stocké dans %s.',
 	'THEME_LOCATION'			=> 'Stocker la feuille de style dans',
 	'THEME_LOCATION_EXPLAIN'	=> 'Les images sont toujours stockées dans le système de fichiers.',
@@ -430,7 +430,7 @@ $lang = array_merge($lang, array(
 	'UNDERLINE'				=> 'Souligné',
 	'UNINSTALLED_IMAGESET'	=> 'Ensembles d’images désinstallés',
 	'UNINSTALLED_STYLE'		=> 'Styles désinstallés',
-	'UNINSTALLED_TEMPLATE'	=> 'Ensembles de templates désinstallés',
+	'UNINSTALLED_TEMPLATE'	=> 'Ensembles de modèles désinstallés',
 	'UNINSTALLED_THEME'		=> 'Thèmes désinstallés',
 	'UNSET'					=> 'Non défini',
 
